<?php
// Version: 1.1.1; index

/*	This template is, perhaps, the most important template in the theme.  It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below.  It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1.1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = false;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = false;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = false;
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />', empty($context['robot_no_index']) ? '' : '
	<meta name="robots" content="noindex" />', '
	<meta name="keywords" content="PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum" />
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>
	<script language="javascript" type="text/javascript" src="', $settings['theme_url'], '/dropdown.js"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
 	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

</head>
<body>';

	// Because of the way width/padding are calculated, we have to tell Internet Explorer 4 and 5 that the content should be 100% wide. (or else it will assume about 108%!)
	echo '
	<div id="headerarea" style="padding: 0px 10px 0px 10px;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">';

	// The logo, and menu.
	echo '
	<div class="board">
<b class="top"><b class="b1"></b><b class="b2"></b><b class="b3"></b><b class="b4"></b></b>
	<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%" style="position: relative;">
		<tr>
		  
			<td class="hedr" height="120" width="100%" valign="middle" align="center"><img src="', $settings['images_url'] . '/theme_logo.gif" alt="" align="right" /></td>
			
		</tr>
		<tr>
    <td class="menu" width="100%" colspan="4" valign="top" align="center" style="border-width: 1px 0 1px 0; font-size: normal; padding: 6px;">';
echo '
			<span class="chromestyle">
    ' , template_menu(), '
		
		</span>';
	echo '
</td> 
	 </tr>
	    </table></div></div>';

	// Show the news fader?  (assuming there are things to show...)
	if ($settings['show_newsfader'] && !empty($context['fader_news_lines']))
	{
		echo '
<div id="infoarea" style="padding: 10px 30px 0px 30px;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
<div class="inset">
<b class="top"><b class="b1"></b><b class="b2"></b><b class="b3"></b><b class="b4"></b></b>
<div class="boxcontent">
<table border="0" width="100%" align="center" cellspacing="0" cellpadding="5" style="border-bottom: 0;">
	<tr>
		<td style="background: #e9f0f6;" valign="middle" align="center" height="50">';

		// Prepare all the javascript settings.
		echo '
			<div id="smfFadeScroller" style="width: 90%; padding: 2px;"><b>', $context['news_lines'][0], '</b></div>
			<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
				// The fading delay (in ms.)
				var smfFadeDelay = ', empty($settings['newsfader_time']) ? 5000 : $settings['newsfader_time'], ';
				// Fade from... what text color?  To which background color?
				var smfFadeFrom = {"r": 0, "g": 0, "b": 0}, smfFadeTo = {"r": 248, "g": 248, "b": 248};
				// Surround each item with... anything special?
				var smfFadeBefore = "<b>", smfFadeAfter = "</b>";

				if (typeof(document.getElementById(\'smfFadeScroller\').currentStyle) != "undefined")
				{
					var foreColor = document.getElementById(\'smfFadeScroller\').currentStyle.color.match(/#([\da-f][\da-f])([\da-f][\da-f])([\da-f][\da-f])/);
					smfFadeFrom = {"r": parseInt(foreColor[1]), "g": parseInt(foreColor[2]), "b": parseInt(foreColor[3])};

					var backEl = document.getElementById(\'smfFadeScroller\');
					while (backEl.currentStyle.backgroundColor == "transparent" && typeof(backEl.parentNode) != "undefined")
						backEl = backEl.parentNode;

					var backColor = backEl.currentStyle.backgroundColor.match(/#([\da-f][\da-f])([\da-f][\da-f])([\da-f][\da-f])/);
					smfFadeTo = {"r": eval("0x" + backColor[1]), "g": eval("0x" + backColor[2]), "b": eval("0x" + backColor[3])};
				}
				else if (typeof(window.opera) == "undefined" && typeof(document.defaultView) != "undefined")
				{
					var foreColor = document.defaultView.getComputedStyle(document.getElementById(\'smfFadeScroller\'), null).color.match(/rgb\((\d+), (\d+), (\d+)\)/);
					smfFadeFrom = {"r": parseInt(foreColor[1]), "g": parseInt(foreColor[2]), "b": parseInt(foreColor[3])};

					var backEl = document.getElementById(\'smfFadeScroller\');
					while (document.defaultView.getComputedStyle(backEl, null).backgroundColor == "transparent" && typeof(backEl.parentNode) != "undefined" && typeof(backEl.parentNode.tagName) != "undefined")
						backEl = backEl.parentNode;

					var backColor = document.defaultView.getComputedStyle(backEl, null).backgroundColor.match(/rgb\((\d+), (\d+), (\d+)\)/);
					smfFadeTo = {"r": parseInt(backColor[1]), "g": parseInt(backColor[2]), "b": parseInt(backColor[3])};
				}

				// List all the lines of the news for display.
				var smfFadeContent = new Array(
					"', implode('",
					"', $context['fader_news_lines']), '"
				);
			// ]]></script>
			<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/fader.js"></script>
		</td>
	</tr>
</table></div>
        <b class="bottom"><b class="b4b"></b><b class="b3b"></b><b class="b2b"></b><b class="b1b"></b></b>
</div></div>';
	}

echo '
	<br />
	<table cellspacing="0" cellpadding="10" border="0" align="center" width="100%">
		<tr><td class="linktext" valign="middle">';

	// If the user is logged in, display stuff like their name, new messages, etc.
	if ($context['user']['is_logged'])
	{
		echo '
				', $txt['hello_member'], ' <b>', $context['user']['name'], '</b>', $context['allow_pm'] ? ', ' . $txt[152] . ' <a href="' . $scripturl . '?action=pm">' . $context['user']['messages'] . ' ' . ($context['user']['messages'] != 1 ? $txt[153] : $txt[471]) . '</a>' . $txt['newmessages4'] . ' ' . $context['user']['unread_messages'] . ' ' . ($context['user']['unread_messages'] == 1 ? $txt['newmessages0'] : $txt['newmessages1']) : '', '.';

		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '<br />
				', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'];

		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '<br />
				<b>', $txt[616], '</b>';
	}
	// Otherwise they're a guest - so politely ask them to register or login.
	else
		echo '
				', $txt['welcome_guest'];

	echo '
				</td><td class="linktext" align="right">', $context['current_time'], '
			</td></tr>';

	echo '
	</table>';
		// Show a vB style login for quick login?
	if ($context['show_quick_login'])
	{
		echo '
	<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
		<tr><td class="linktext" nowrap="nowrap" align="center">
			<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>

			<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '><br />
				<input type="text" name="user" size="7" />
				<input type="password" name="passwrd" size="7" />
				<select name="cookielength">
					<option value="60">', $txt['smf53'], '</option>
					<option value="1440">', $txt['smf47'], '</option>
					<option value="10080">', $txt['smf48'], '</option>
					<option value="43200">', $txt['smf49'], '</option>
					<option value="-1" selected="selected">', $txt['smf50'], '</option>
				</select>
				<input type="submit" value="', $txt[34], '" /><br />
				', $txt['smf52'], '
				<input type="hidden" name="hash_passwrd" value="" />
			</form>
		</td></tr>
	</table></div>';
	}

	// Don't show a login box, just a break.
	else
		echo '
	<br /><br />';
	

	// The main content should go here.  A table is used because IE 6 just can't handle a div.
        echo '<div id="bodyarea" style="padding: 0px 10px 0px 10px;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
	
	<table cellspacing="0" cellpadding="0" border="0" align="center" width="100%">
		<tr><td valign="top">';
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
		</td></tr></table></div>';


	// Show the "Powered by" and "Valid" logos, as well as the copyright.  Remember, the copyright must be somewhere!
	echo '
	<br />
<div id="footerarea" style="text-align: center; padding-bottom: 1ex;', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			function smfFooterHighlight(element, value)
			{
				element.src = smf_images_url + "/" + (value ? "h_" : "") + element.id + ".gif";
			}
		// ]]></script>
		
	<table cellspacing="0" cellpadding="3" border="0" align="center" width="100%" style="padding: 0 0 30px 0;">
			<tr>
				<td class="linktext" width="20%" valign="middle" align="', !$context['right_to_left'] ? 'right' : 'left', '">
				<small>HazePurple by:<a href="http://global-bttracker.no-ip.org/forum/" target="_blank">TreetopClimber</a> &copy; 2007</small>
				</td>
				<td class="linktext" width="60%" valign="middle" align="center" style="white-space: nowrap;">
				<small> 
					', theme_copyright(), '   
				</small></td>
				<td class="linktext" width="20%" valign="middle" align="', !$context['right_to_left'] ? 'left' : 'right', '">
				<a href="http://validator.w3.org/check/referer" target="_blank">XHTML</a> | <a href="http://jigsaw.w3.org/css-validator/check/referer" target="_blank">CSS</a> | <a href="http://www.mysql.com/" target="_blank">MySQL</a> | <a href="http://www.php.net/" target="_blank">PHP</a>
				</td>
			</tr>
		</table></div>';

	// Show the load time?
	if ($context['show_load_time'])
		echo '
		<span class="smalltext">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</span>';

	// This is an interesting bug in Internet Explorer AND Safari. Rather annoying, it makes overflows just not tall enough.
	if (($context['browser']['is_ie'] && !$context['browser']['is_ie4']) || $context['browser']['is_mac_ie'] || $context['browser']['is_safari'] || $context['browser']['is_firefox'])
	{
		// The purpose of this code is to fix the height of overflow: auto div blocks, because IE can't figure it out for itself.
		echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[';

		// Unfortunately, Safari does not have a "getComputedStyle" implementation yet, so we have to just do it to code...
		if ($context['browser']['is_safari'])
			echo '
			window.addEventListener("load", smf_codeFix, false);

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if ((codeFix[i].className == "code" || codeFix[i].className == "post" || codeFix[i].className == "signature") && codeFix[i].offsetHeight < 20)
						codeFix[i].style.height = (codeFix[i].offsetHeight + 20) + "px";
				}
			}';
		elseif ($context['browser']['is_firefox'])
			echo '
			window.addEventListener("load", smf_codeFix, false);
			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if (codeFix[i].className == "code" && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0))
						codeFix[i].style.overflow = "scroll";
				}
			}';
		else
			echo '
			var window_oldOnload = window.onload;
			window.onload = smf_codeFix;

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = codeFix.length - 1; i > 0; i--)
				{
					if (codeFix[i].currentStyle.overflow == "auto" && (codeFix[i].currentStyle.height == "" || codeFix[i].currentStyle.height == "auto") && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0) && (codeFix[i].offsetHeight != 0 || codeFix[i].className == "code"))
						codeFix[i].style.height = (codeFix[i].offsetHeight + 36) + "px";
				}

				if (window_oldOnload)
				{
					window_oldOnload();
					window_oldOnload = null;
				}
			}';

		echo '
		// ]]></script>';
	}
	// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div>
';
	echo '
</body>
</html>';
}

// Show a linktree.  This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	// Folder style or inline?  Inline has a smaller font.
	echo '<span class="nav"', $settings['linktree_inline'] ? ' style="font-size: smaller;"' : '', '>';

	// Each tree item has a URL and name.  Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show the | | |-[] Folders.
		if (!$settings['linktree_inline'])
		{
			if ($link_num > 0)
				echo str_repeat('<img src="' . $settings['images_url'] . '/icons/linktree_main.gif" alt="| " border="0" />', $link_num - 1), '<img src="' . $settings['images_url'] . '/icons/linktree_side.gif" alt="|-" border="0" />';
			echo '<img src="' . $settings['images_url'] . '/icons/folder_open.gif" alt="+" border="0" />&nbsp; ';
		}

		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo $settings['linktree_inline'] ? '&nbsp;<img src="' . $settings['images_url'] . '/icons/nav.gif" alt="" border="0" />&nbsp;' : '<br />';
	}

	echo '</span>';
}

// Show the menu up top.  Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Show the [home] and [help] buttons.
  echo '
<a href="', $scripturl, '">' .$txt[103] . '</a>', $context['menu_separator'], '
<a href="', $scripturl, '?action=help">' . $txt[119] . '</a>', $context['menu_separator'];

/* <!-- TPortal Section  -->
if($settings['TPortal_front_type']!='boardindex')
	// Show the [forum] button.
	echo '
<a href="', $scripturl, '?action=forum">'.$txt['tp-forum'].'</a>', $context['menu_separator'];*//*

  // How about the [downloads] button?
	if ($context['user']['is_logged'])
echo '
<a href="', $scripturl, '#dwnldlinks" onmouseover="return overlay(this, \'dwnldlinks\',\'bottom\')">' . $txt[dwnldlinks] . '&nbsp;</a>
				<!--Do not remove outer most DIV tag with id="downldlinks"-->
<DIV id="dwnldlinks" style="position:absolute; border: 2px solid #7f0cab; background-color: #dab5e9; width: 150px; padding: 2px; display:none">';

   if ($context['user']['is_logged'])
		echo '
<a class="subDwn-link" href="', $scripturl, '?action=tpmod;dl=upload">' . $txt[tp-dlupload] . '</a>';

echo '
<a class="subDwn-link" href="#" onmouseout="overlayclose(\'downldlinks\'); return false"></a>
</DIV>';
<!-- End TPortal Section  --> */
   // How about the [admin info] button?
	if ($context['allow_admin'])
echo ' 
<a href="', $scripturl, '#adminlinks" onmouseover="return overlay(this, \'adminlinks\',\'bottom\')">' . $txt[adminlinks] . '&nbsp;</a>
				<!--Do not remove outer most DIV tag with id="adminlinks"-->
<DIV id="adminlinks" style="position:absolute; border: 2px solid #7f0cab; background-color: #dab5e9; width: 150px; padding: 2px; display:none">';
		// Is the user allowed to administrate at all? ([admin])
	if ($context['allow_admin'])
		echo '
<a class="subPro-link" href="', $scripturl, '?action=admin">Admin Main</a>
<a class="subPro-link" href="', $scripturl, '?action=news">' . $txt[102] . '</a>
<a class="subPro-link" href="', $scripturl, '?action=packages">Packages</a>
<a class="subPro-link" href="', $scripturl, '?action=manageboards">Boards</a>
<a class="subPro-link" href="', $scripturl, '?action=postsettings">Post & Topics</a>
<a class="subPro-link" href="#" onmouseout="overlayclose(\'adminlinks\'); return false"></a>
</DIV>', $context['menu_separator'];
// How about the [search] button?
    if ($context['user']['is_logged'])
		echo '
<a href="', $scripturl, '?action=search">' . $txt[182] . '</a>', $context['menu_separator'];

// How about the [user info] button?
	if ($context['user']['is_logged'])
echo '
<a href="', $scripturl, '#userlinks" onmouseover="return overlay(this, \'userlinks\',\'bottom\')">' . $txt[userlinks] . '&nbsp;</a>
				<!--Do not remove outer most DIV tag with id="userlinks"-->
<DIV id="userlinks" style="position:absolute; border: 2px solid #7f0cab; background-color: #dab5e9; width: 150px; padding: 2px; display:none">';
	// Edit Profile... [profile]
	if ($context['allow_edit_profile'])
		echo '

<a class="subMenu-link" href="', $scripturl, '?action=profile">' . $txt[79] . ' Main</a>
<a class="subMenu-link" href="', $scripturl, '?action=profile;u=', $context['user']['id'], ';sa=forumProfile">Forum Info</a>
<a class="subMenu-link" href="', $scripturl, '?action=profile;u=', $context['user']['id'], ';sa=account">Account Settings</a>
<a class="subMenu-link" href="', $scripturl, '?action=profile;u=', $context['user']['id'], ';sa=theme">Look & Layout</a>
<a class="subMenu-link" href="', $scripturl, '?action=pm">' . $txt[pm_short] . '</a>
<a class="subMenu-link" href="#" onmouseout="overlayclose(\'userlinks\'); return true"></a>
</DIV>', $context['menu_separator'];

  // The [calendar]!
	if ($context['allow_calendar'])
		echo '
<a href="', $scripturl, '?action=calendar">' . $txt['calendar24'] . '</a>', $context['menu_separator'];
  

	// If the user is a guest, show [login] and [register] buttons.
	if ($context['user']['is_guest'])
	{
		echo '
<a href="', $scripturl, '?action=login">' . $txt[34] . '</a>', $context['menu_separator'], '
<a href="', $scripturl, '?action=register">' . $txt[97] . '</a>', $context['menu_separator'];
	}
	// Otherwise, they might want to [logout]...
	else
		echo '
<a href="', $scripturl, '?action=logout;sesc=', $context['session_id'], '">' . $txt[108] . '</a>';	
}

// Generate a strip of buttons, out of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	if (empty($button_strip))
		return '';

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
			$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . ($settings['use_image_buttons'] ? '<img src="' . $settings['images_url'] . '/' . ($value['lang'] ? $context['user']['language'] . '/' : '') . $value['image'] . '" alt="' . $txt[$value['text']] . '" border="0" />' : $txt[$value['text']]) . '</a>';

		$button_strip[$key] = $buttons[$key];
	}

	echo '
		<td ', $custom_td, '>', implode($context['menu_separator'], $button_strip) , '</td>';
}

?>